==> opennms-model-1.13.1-20140421.215247-178-sources.jar: org/opennms/netmgt/model/OnmsAlarmCollection.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2008-2012 The OpenNMS Alarm, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Alarm, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Alarm, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model;

import java.util.Collection;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.core.config.api.JaxbListWrapper;

@XmlRootElement(name="alarms")
public class OnmsAlarmCollection extends JaxbListWrapper<OnmsAlarm> {
    private static final long serialVersionUID = 1L;

    public OnmsAlarmCollection() { super(); }
    public OnmsAlarmCollection(final Collection<? extends OnmsAlarm> alarms) {
        super(alarms);
    }

    @XmlElement(name="alarm")
    public List<OnmsAlarm> getObjects() {
        return super.getObjects();
    }
}

==> opennms-model-21.1.0-20200321.174718-111-sources.jar: org/opennms/netmgt/model/OnmsAlarmCollection.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2008-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model;

import java.util.Collection;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.codehaus.jackson.annotate.JsonProperty;
import org.codehaus.jackson.map.annotate.JsonRootName;
import org.opennms.core.config.api.JaxbListWrapper;

@XmlRootElement(name="alarms")
@JsonRootName("alarms")
public class OnmsAlarmCollection extends JaxbListWrapper<OnmsAlarm> {
    private static final long serialVersionUID = 1L;

    public OnmsAlarmCollection() { super(); }
    public OnmsAlarmCollection(final Collection<? extends OnmsAlarm> alarms) {
        super(alarms);
    }

    @XmlElement(name="alarm")
    @JsonProperty("alarm")
    public List<OnmsAlarm> getObjects() {
        return super.getObjects();
    }
}
